day_names = {
    "en": (
        "Monday",
        "Tuesday",
        "Wednesday",
        "Thursday",
        "Friday",
        "Saturday",
        "Sunday",
    ),
    "ar": (
        "الاثنين",
        "الثلاثاء",
        "الأربعاء",
        "الخميس",
        "الجمعة",
        "السبت",
        "الأحد",
    ),
}


class Lunar:
    """Umm al-Qura lunar calendar specific constants.

    month_names: Month names in English and Arabic languages.

    valid_range: Range of expected dates for correct conversion
                 (including the end)

    first_offset: Total months from epoch of lunar calendar to the the
                  first month in `valid_range`.

    month_starts: Reduced Julian Day Numbers for first day of months
                  within `valid_range`.
    """

    month_names = {
        "en": (
            "",
            "Muharram",
            "Safar",
            "Rabi’ al-Awwal",
            "Rabi’ al-Thani",
            "Jumada al-Ula",
            "Jumada al-Akhirah",
            "Rajab",
            "Sha’ban",
            "Ramadhan",
            "Shawwal",
            "Dhul-Qi’dah",
            "Dhul-Hijjah",
        ),
        "ar": (
            "",
            "محرم",
            "صفر",
            "ربيع الأول",
            "ربيع الثاني",
            "جمادى الأولى",
            "جمادى الآخرة",
            "رجب",
            "شعبان",
            "رمضان",
            "شوال",
            "ذو القعدة",
            "ذو الحجة",
        ),
    }
    valid_range = (1356, 1, 1), (1500, 12, 30)
    first_offset = 1355 * 12
    month_starts = (
        28607,
        28636,
        28665,
        28695,
        28724,
        28754,
        28783,
        28813,
        28843,
        28872,
        28901,
        28931,
        28960,
        28990,
        29019,
        29049,
        29078,
        29108,
        29137,
        29167,
        29196,
        29226,
        29255,
        29285,
        29315,
        29345,
        29375,
        29404,
        29434,
        29463,
        29492,
        29522,
        29551,
        29580,
        29610,
        29640,
        29669,
        29699,
        29729,
        29759,
        29788,
        29818,
        29847,
        29876,
        29906,
        29935,
        29964,
        29994,
        30023,
        30053,
        30082,
        30112,
        30141,
        30171,
        30200,
        30230,
        30259,
        30289,
        30318,
        30348,
        30378,
        30408,
        30437,
        30467,
        30496,
        30526,
        30555,
        30585,
        30614,
        30644,
        30673,
        30703,
        30732,
        30762,
        30791,
        30821,
        30850,
        30880,
        30909,
        30939,
        30968,
        30998,
        31027,
        31057,
        31086,
        31116,
        31145,
        31175,
        31204,
        31234,
        31263,
        31293,
        31322,
        31352,
        31381,
        31411,
        31441,
        31471,
        31500,
        31530,
        31559,
        31589,
        31618,
        31648,
        31676,
        31706,
        31736,
        31766,
        31795,
        31825,
        31854,
        31884,
        31913,
        31943,
        31972,
        32002,
        32031,
        32061,
        32090,
        32120,
        32150,
        32180,
        32209,
        32239,
        32268,
        32298,
        32327,
        32357,
        32386,
        32416,
        32445,
        32475,
        32504,
        32534,
        32563,
        32593,
        32622,
        32652,
        32681,
        32711,
        32740,
        32770,
        32799,
        32829,
        32858,
        32888,
        32917,
        32947,
        32976,
        33006,
        33035,
        33065,
        33094,
        33124,
        33153,
        33183,
        33213,
        33243,
        33272,
        33302,
        33331,
        33361,
        33390,
        33420,
        33450,
        33479,
        33509,
        33539,
        33568,
        33598,
        33627,
        33657,
        33686,
        33716,
        33745,
        33775,
        33804,
        33834,
        33863,
        33893,
        33922,
        33952,
        33981,
        34011,
        34040,
        34069,
        34099,
        34128,
        34158,
        34187,
        34217,
        34247,
        34277,
        34306,
        34336,
        34365,
        34395,
        34424,
        34454,
        34483,
        34512,
        34542,
        34571,
        34601,
        34631,
        34660,
        34690,
        34719,
        34749,
        34778,
        34808,
        34837,
        34867,
        34896,
        34926,
        34955,
        34985,
        35015,
        35044,
        35074,
        35103,
        35133,
        35162,
        35192,
        35222,
        35251,
        35280,
        35310,
        35340,
        35370,
        35399,
        35429,
        35458,
        35488,
        35517,
        35547,
        35576,
        35605,
        35635,
        35665,
        35694,
        35723,
        35753,
        35782,
        35811,
        35841,
        35871,
        35901,
        35930,
        35960,
        35989,
        36019,
        36048,
        36078,
        36107,
        36136,
        36166,
        36195,
        36225,
        36254,
        36284,
        36314,
        36343,
        36373,
        36403,
        36433,
        36462,
        36492,
        36521,
        36551,
        36580,
        36610,
        36639,
        36669,
        36698,
        36728,
        36757,
        36786,
        36816,
        36845,
        36875,
        36904,
        36934,
        36963,
        36993,
        37022,
        37052,
        37081,
        37111,
        37141,
        37170,
        37200,
        37229,
        37259,
        37288,
        37318,
        37347,
        37377,
        37406,
        37436,
        37465,
        37495,
        37524,
        37554,
        37584,
        37613,
        37643,
        37672,
        37701,
        37731,
        37760,
        37790,
        37819,
        37849,
        37878,
        37908,
        37938,
        37967,
        37997,
        38027,
        38056,
        38085,
        38115,
        38144,
        38174,
        38203,
        38233,
        38262,
        38292,
        38322,
        38351,
        38381,
        38410,
        38440,
        38469,
        38499,
        38528,
        38558,
        38587,
        38617,
        38646,
        38676,
        38705,
        38735,
        38764,
        38794,
        38823,
        38853,
        38882,
        38912,
        38941,
        38971,
        39001,
        39030,
        39059,
        39089,
        39118,
        39148,
        39178,
        39208,
        39237,
        39267,
        39297,
        39326,
        39355,
        39385,
        39414,
        39444,
        39473,
        39503,
        39532,
        39562,
        39592,
        39621,
        39650,
        39680,
        39709,
        39739,
        39768,
        39798,
        39827,
        39857,
        39886,
        39916,
        39946,
        39975,
        40005,
        40035,
        40064,
        40094,
        40123,
        40153,
        40182,
        40212,
        40241,
        40271,
        40300,
        40330,
        40359,
        40389,
        40418,
        40448,
        40477,
        40507,
        40536,
        40566,
        40595,
        40625,
        40655,
        40685,
        40714,
        40744,
        40773,
        40803,
        40832,
        40862,
        40892,
        40921,
        40951,
        40980,
        41009,
        41039,
        41068,
        41098,
        41127,
        41157,
        41186,
        41216,
        41245,
        41275,
        41304,
        41334,
        41364,
        41393,
        41422,
        41452,
        41481,
        41511,
        41540,
        41570,
        41599,
        41629,
        41658,
        41688,
        41718,
        41748,
        41777,
        41807,
        41836,
        41865,
        41894,
        41924,
        41953,
        41983,
        42012,
        42042,
        42072,
        42102,
        42131,
        42161,
        42190,
        42220,
        42249,
        42279,
        42308,
        42337,
        42367,
        42397,
        42426,
        42456,
        42485,
        42515,
        42545,
        42574,
        42604,
        42633,
        42662,
        42692,
        42721,
        42751,
        42780,
        42810,
        42839,
        42869,
        42899,
        42929,
        42958,
        42988,
        43017,
        43046,
        43076,
        43105,
        43135,
        43164,
        43194,
        43223,
        43253,
        43283,
        43312,
        43342,
        43371,
        43401,
        43430,
        43460,
        43489,
        43519,
        43548,
        43578,
        43607,
        43637,
        43666,
        43696,
        43726,
        43755,
        43785,
        43814,
        43844,
        43873,
        43903,
        43932,
        43962,
        43991,
        44021,
        44050,
        44080,
        44109,
        44139,
        44169,
        44198,
        44228,
        44258,
        44287,
        44317,
        44346,
        44375,
        44405,
        44434,
        44464,
        44493,
        44523,
        44553,
        44582,
        44612,
        44641,
        44671,
        44700,
        44730,
        44759,
        44788,
        44818,
        44847,
        44877,
        44906,
        44936,
        44966,
        44996,
        45025,
        45055,
        45084,
        45114,
        45143,
        45172,
        45202,
        45231,
        45261,
        45290,
        45320,
        45350,
        45380,
        45409,
        45439,
        45468,
        45498,
        45527,
        45556,
        45586,
        45615,
        45644,
        45674,
        45704,
        45733,
        45763,
        45793,
        45823,
        45852,
        45882,
        45911,
        45940,
        45970,
        45999,
        46028,
        46058,
        46088,
        46117,
        46147,
        46177,
        46206,
        46236,
        46265,
        46295,
        46324,
        46354,
        46383,
        46413,
        46442,
        46472,
        46501,
        46531,
        46560,
        46590,
        46620,
        46649,
        46679,
        46708,
        46738,
        46767,
        46797,
        46826,
        46856,
        46885,
        46915,
        46944,
        46974,
        47003,
        47033,
        47063,
        47092,
        47122,
        47151,
        47181,
        47210,
        47240,
        47269,
        47298,
        47328,
        47357,
        47387,
        47417,
        47446,
        47476,
        47506,
        47535,
        47565,
        47594,
        47624,
        47653,
        47682,
        47712,
        47741,
        47771,
        47800,
        47830,
        47860,
        47890,
        47919,
        47949,
        47978,
        48008,
        48037,
        48066,
        48096,
        48125,
        48155,
        48184,
        48214,
        48244,
        48273,
        48303,
        48333,
        48362,
        48392,
        48421,
        48450,
        48480,
        48509,
        48538,
        48568,
        48598,
        48627,
        48657,
        48687,
        48717,
        48746,
        48776,
        48805,
        48834,
        48864,
        48893,
        48922,
        48952,
        48982,
        49011,
        49041,
        49071,
        49100,
        49130,
        49160,
        49189,
        49218,
        49248,
        49277,
        49306,
        49336,
        49365,
        49395,
        49425,
        49455,
        49484,
        49514,
        49543,
        49573,
        49602,
        49632,
        49661,
        49690,
        49720,
        49749,
        49779,
        49809,
        49838,
        49868,
        49898,
        49927,
        49957,
        49986,
        50016,
        50045,
        50075,
        50104,
        50133,
        50163,
        50192,
        50222,
        50252,
        50281,
        50311,
        50340,
        50370,
        50400,
        50429,
        50459,
        50488,
        50518,
        50547,
        50576,
        50606,
        50635,
        50665,
        50694,
        50724,
        50754,
        50784,
        50813,
        50843,
        50872,
        50902,
        50931,
        50960,
        50990,
        51019,
        51049,
        51078,
        51108,
        51138,
        51167,
        51197,
        51227,
        51256,
        51286,
        51315,
        51345,
        51374,
        51403,
        51433,
        51462,
        51492,
        51522,
        51552,
        51582,
        51611,
        51641,
        51670,
        51699,
        51729,
        51758,
        51787,
        51816,
        51846,
        51876,
        51906,
        51936,
        51965,
        51995,
        52025,
        52054,
        52083,
        52113,
        52142,
        52171,
        52200,
        52230,
        52260,
        52290,
        52319,
        52349,
        52379,
        52408,
        52438,
        52467,
        52497,
        52526,
        52555,
        52585,
        52614,
        52644,
        52673,
        52703,
        52733,
        52762,
        52792,
        52822,
        52851,
        52881,
        52910,
        52939,
        52969,
        52998,
        53028,
        53057,
        53087,
        53116,
        53146,
        53176,
        53205,
        53235,
        53264,
        53294,
        53324,
        53353,
        53383,
        53412,
        53441,
        53471,
        53500,
        53530,
        53559,
        53589,
        53619,
        53648,
        53678,
        53708,
        53737,
        53767,
        53796,
        53825,
        53855,
        53884,
        53913,
        53943,
        53973,
        54003,
        54032,
        54062,
        54092,
        54121,
        54151,
        54180,
        54209,
        54239,
        54268,
        54297,
        54327,
        54357,
        54387,
        54416,
        54446,
        54476,
        54505,
        54535,
        54564,
        54593,
        54623,
        54652,
        54681,
        54711,
        54741,
        54770,
        54800,
        54830,
        54859,
        54889,
        54919,
        54948,
        54977,
        55007,
        55036,
        55066,
        55095,
        55125,
        55154,
        55184,
        55213,
        55243,
        55273,
        55302,
        55332,
        55361,
        55391,
        55420,
        55450,
        55479,
        55508,
        55538,
        55567,
        55597,
        55627,
        55657,
        55686,
        55716,
        55745,
        55775,
        55804,
        55834,
        55863,
        55892,
        55922,
        55951,
        55981,
        56011,
        56040,
        56070,
        56100,
        56129,
        56159,
        56188,
        56218,
        56247,
        56276,
        56306,
        56335,
        56365,
        56394,
        56424,
        56454,
        56483,
        56513,
        56543,
        56572,
        56601,
        56631,
        56660,
        56690,
        56719,
        56749,
        56778,
        56808,
        56837,
        56867,
        56897,
        56926,
        56956,
        56985,
        57015,
        57044,
        57074,
        57103,
        57133,
        57162,
        57192,
        57221,
        57251,
        57280,
        57310,
        57340,
        57369,
        57399,
        57429,
        57458,
        57487,
        57517,
        57546,
        57576,
        57605,
        57634,
        57664,
        57694,
        57723,
        57753,
        57783,
        57813,
        57842,
        57871,
        57901,
        57930,
        57959,
        57989,
        58018,
        58048,
        58077,
        58107,
        58137,
        58167,
        58196,
        58226,
        58255,
        58285,
        58314,
        58343,
        58373,
        58402,
        58432,
        58461,
        58491,
        58521,
        58551,
        58580,
        58610,
        58639,
        58669,
        58698,
        58727,
        58757,
        58786,
        58816,
        58845,
        58875,
        58905,
        58934,
        58964,
        58994,
        59023,
        59053,
        59082,
        59111,
        59141,
        59170,
        59200,
        59229,
        59259,
        59288,
        59318,
        59348,
        59377,
        59407,
        59436,
        59466,
        59495,
        59525,
        59554,
        59584,
        59613,
        59643,
        59672,
        59702,
        59731,
        59761,
        59791,
        59820,
        59850,
        59879,
        59909,
        59939,
        59968,
        59997,
        60027,
        60056,
        60086,
        60115,
        60145,
        60174,
        60204,
        60234,
        60264,
        60293,
        60323,
        60352,
        60381,
        60411,
        60440,
        60469,
        60499,
        60528,
        60558,
        60588,
        60618,
        60648,
        60677,
        60707,
        60736,
        60765,
        60795,
        60824,
        60853,
        60883,
        60912,
        60942,
        60972,
        61002,
        61031,
        61061,
        61090,
        61120,
        61149,
        61179,
        61208,
        61237,
        61267,
        61296,
        61326,
        61356,
        61385,
        61415,
        61445,
        61474,
        61504,
        61533,
        61563,
        61592,
        61621,
        61651,
        61680,
        61710,
        61739,
        61769,
        61799,
        61828,
        61858,
        61888,
        61917,
        61947,
        61976,
        62006,
        62035,
        62064,
        62094,
        62123,
        62153,
        62182,
        62212,
        62242,
        62271,
        62301,
        62331,
        62360,
        62390,
        62419,
        62448,
        62478,
        62507,
        62537,
        62566,
        62596,
        62625,
        62655,
        62685,
        62715,
        62744,
        62774,
        62803,
        62832,
        62862,
        62891,
        62921,
        62950,
        62980,
        63009,
        63039,
        63069,
        63099,
        63128,
        63157,
        63187,
        63216,
        63246,
        63275,
        63305,
        63334,
        63363,
        63393,
        63423,
        63453,
        63482,
        63512,
        63541,
        63571,
        63600,
        63630,
        63659,
        63689,
        63718,
        63747,
        63777,
        63807,
        63836,
        63866,
        63895,
        63925,
        63955,
        63984,
        64014,
        64043,
        64073,
        64102,
        64131,
        64161,
        64190,
        64220,
        64249,
        64279,
        64309,
        64339,
        64368,
        64398,
        64427,
        64457,
        64486,
        64515,
        64545,
        64574,
        64603,
        64633,
        64663,
        64692,
        64722,
        64752,
        64782,
        64811,
        64841,
        64870,
        64899,
        64929,
        64958,
        64987,
        65017,
        65047,
        65076,
        65106,
        65136,
        65166,
        65195,
        65225,
        65254,
        65283,
        65313,
        65342,
        65371,
        65401,
        65431,
        65460,
        65490,
        65520,
        65549,
        65579,
        65608,
        65638,
        65667,
        65697,
        65726,
        65755,
        65785,
        65815,
        65844,
        65874,
        65903,
        65933,
        65963,
        65992,
        66022,
        66051,
        66081,
        66110,
        66140,
        66169,
        66199,
        66228,
        66258,
        66287,
        66317,
        66346,
        66376,
        66405,
        66435,
        66465,
        66494,
        66524,
        66553,
        66583,
        66612,
        66641,
        66671,
        66700,
        66730,
        66760,
        66789,
        66819,
        66849,
        66878,
        66908,
        66937,
        66967,
        66996,
        67025,
        67055,
        67084,
        67114,
        67143,
        67173,
        67203,
        67233,
        67262,
        67292,
        67321,
        67351,
        67380,
        67409,
        67439,
        67468,
        67497,
        67527,
        67557,
        67587,
        67617,
        67646,
        67676,
        67705,
        67735,
        67764,
        67793,
        67823,
        67852,
        67882,
        67911,
        67941,
        67971,
        68000,
        68030,
        68060,
        68089,
        68119,
        68148,
        68177,
        68207,
        68236,
        68266,
        68295,
        68325,
        68354,
        68384,
        68414,
        68443,
        68473,
        68502,
        68532,
        68561,
        68591,
        68620,
        68650,
        68679,
        68708,
        68738,
        68768,
        68797,
        68827,
        68857,
        68886,
        68916,
        68946,
        68975,
        69004,
        69034,
        69063,
        69092,
        69122,
        69152,
        69181,
        69211,
        69240,
        69270,
        69300,
        69330,
        69359,
        69388,
        69418,
        69447,
        69476,
        69506,
        69535,
        69565,
        69595,
        69624,
        69654,
        69684,
        69713,
        69743,
        69772,
        69802,
        69831,
        69861,
        69890,
        69919,
        69949,
        69978,
        70008,
        70038,
        70067,
        70097,
        70126,
        70156,
        70186,
        70215,
        70245,
        70274,
        70303,
        70333,
        70362,
        70392,
        70421,
        70451,
        70481,
        70510,
        70540,
        70570,
        70599,
        70629,
        70658,
        70687,
        70717,
        70746,
        70776,
        70805,
        70835,
        70864,
        70894,
        70924,
        70954,
        70983,
        71013,
        71042,
        71071,
        71101,
        71130,
        71159,
        71189,
        71218,
        71248,
        71278,
        71308,
        71337,
        71367,
        71397,
        71426,
        71455,
        71485,
        71514,
        71543,
        71573,
        71602,
        71632,
        71662,
        71691,
        71721,
        71751,
        71781,
        71810,
        71839,
        71869,
        71898,
        71927,
        71957,
        71986,
        72016,
        72046,
        72075,
        72105,
        72135,
        72164,
        72194,
        72223,
        72253,
        72282,
        72311,
        72341,
        72370,
        72400,
        72429,
        72459,
        72489,
        72518,
        72548,
        72577,
        72607,
        72637,
        72666,
        72695,
        72725,
        72754,
        72784,
        72813,
        72843,
        72872,
        72902,
        72931,
        72961,
        72991,
        73020,
        73050,
        73080,
        73109,
        73139,
        73168,
        73197,
        73227,
        73256,
        73286,
        73315,
        73345,
        73375,
        73404,
        73434,
        73464,
        73493,
        73523,
        73552,
        73581,
        73611,
        73640,
        73669,
        73699,
        73729,
        73758,
        73788,
        73818,
        73848,
        73877,
        73907,
        73936,
        73965,
        73995,
        74024,
        74053,
        74083,
        74113,
        74142,
        74172,
        74202,
        74231,
        74261,
        74291,
        74320,
        74349,
        74379,
        74408,
        74437,
        74467,
        74497,
        74526,
        74556,
        74586,
        74615,
        74645,
        74675,
        74704,
        74733,
        74763,
        74792,
        74822,
        74851,
        74881,
        74910,
        74940,
        74969,
        74999,
        75029,
        75058,
        75088,
        75117,
        75147,
        75176,
        75206,
        75235,
        75264,
        75294,
        75323,
        75353,
        75383,
        75412,
        75442,
        75472,
        75501,
        75531,
        75560,
        75590,
        75619,
        75648,
        75678,
        75707,
        75737,
        75766,
        75796,
        75826,
        75856,
        75885,
        75915,
        75944,
        75974,
        76003,
        76032,
        76062,
        76091,
        76121,
        76150,
        76180,
        76210,
        76239,
        76269,
        76299,
        76328,
        76358,
        76387,
        76416,
        76446,
        76475,
        76505,
        76534,
        76564,
        76593,
        76623,
        76653,
        76682,
        76712,
        76741,
        76771,
        76801,
        76830,
        76859,
        76889,
        76918,
        76948,
        76977,
        77007,
        77036,
        77066,
        77096,
        77125,
        77155,
        77185,
        77214,
        77243,
        77273,
        77302,
        77332,
        77361,
        77390,
        77420,
        77450,
        77479,
        77509,
        77539,
        77569,
        77598,
        77627,
        77657,
        77686,
        77715,
        77745,
        77774,
        77804,
        77833,
        77863,
        77893,
        77923,
        77952,
        77982,
        78011,
        78041,
        78070,
        78099,
        78129,
        78158,
        78188,
        78217,
        78247,
        78277,
        78307,
        78336,
        78366,
        78395,
        78425,
        78454,
        78483,
        78513,
        78542,
        78572,
        78601,
        78631,
        78661,
        78690,
        78720,
        78750,
        78779,
        78808,
        78838,
        78867,
        78897,
        78926,
        78956,
        78985,
        79015,
        79044,
        79074,
        79104,
        79133,
        79163,
        79192,
        79222,
        79251,
        79281,
        79310,
        79340,
        79369,
        79399,
        79428,
        79458,
        79487,
        79517,
        79546,
        79576,
        79606,
        79635,
        79665,
        79695,
        79724,
        79753,
        79783,
        79812,
        79841,
        79871,
        79900,
        79930,
        79960,
        79990,
    )


class Solar:
    """Umm al-Qura solar calendar specific constants.

    month_names: Month names in English and Arabic languages.

    valid_range: Range of expected dates for correct conversion
                 (including the end)

    first_offset: Total months from epoch of solar calendar to the the
                  first month in `valid_range`.

    month_starts: Reduced Julian Day Numbers for first day of months
                  within `valid_range`.
    """

    month_names = {
        "en": (
            "",
            "Libra",
            "Scorpio",
            "Sagittarius",
            "Capricorn",
            "Aquarius",
            "Pisces",
            "Aries",
            "Taurus",
            "Gemini",
            "Cancer",
            "Leo",
            "Virgo",
        ),
        "ar": (
            "",
            "الميزان",
            "العقرب",
            "القوس",
            "الجدي",
            "الدلو",
            "الحوت",
            "الحمل",
            "الثور",
            "الجوزاء",
            "السرطان",
            "الأسد",
            "السنبلة",
        ),
    }
    valid_range = (1315, 6, 23), (1456, 2, 25)
    first_offset = 1314 * 12 + 5
    month_starts = (
        28585,
        28614,
        28645,
        28676,
        28707,
        28738,
        28769,
        28800,
        28830,
        28860,
        28890,
        28920,
        28950,
        28979,
        29010,
        29041,
        29072,
        29103,
        29134,
        29165,
        29195,
        29225,
        29255,
        29285,
        29315,
        29344,
        29375,
        29406,
        29437,
        29468,
        29499,
        29530,
        29560,
        29590,
        29620,
        29650,
        29680,
        29710,
        29741,
        29772,
        29803,
        29834,
        29865,
        29896,
        29926,
        29956,
        29986,
        30016,
        30046,
        30075,
        30106,
        30137,
        30168,
        30199,
        30230,
        30261,
        30291,
        30321,
        30351,
        30381,
        30411,
        30440,
        30471,
        30502,
        30533,
        30564,
        30595,
        30626,
        30656,
        30686,
        30716,
        30746,
        30776,
        30805,
        30836,
        30867,
        30898,
        30929,
        30960,
        30991,
        31021,
        31051,
        31081,
        31111,
        31141,
        31171,
        31202,
        31233,
        31264,
        31295,
        31326,
        31357,
        31387,
        31417,
        31447,
        31477,
        31507,
        31536,
        31567,
        31598,
        31629,
        31660,
        31691,
        31722,
        31752,
        31782,
        31812,
        31842,
        31872,
        31901,
        31932,
        31963,
        31994,
        32025,
        32056,
        32087,
        32117,
        32147,
        32177,
        32207,
        32237,
        32266,
        32297,
        32328,
        32359,
        32390,
        32421,
        32452,
        32482,
        32512,
        32542,
        32572,
        32602,
        32632,
        32663,
        32694,
        32725,
        32756,
        32787,
        32818,
        32848,
        32878,
        32908,
        32938,
        32968,
        32997,
        33028,
        33059,
        33090,
        33121,
        33152,
        33183,
        33213,
        33243,
        33273,
        33303,
        33333,
        33362,
        33393,
        33424,
        33455,
        33486,
        33517,
        33548,
        33578,
        33608,
        33638,
        33668,
        33698,
        33727,
        33758,
        33789,
        33820,
        33851,
        33882,
        33913,
        33943,
        33973,
        34003,
        34033,
        34063,
        34093,
        34124,
        34155,
        34186,
        34217,
        34248,
        34279,
        34309,
        34339,
        34369,
        34399,
        34429,
        34458,
        34489,
        34520,
        34551,
        34582,
        34613,
        34644,
        34674,
        34704,
        34734,
        34764,
        34794,
        34823,
        34854,
        34885,
        34916,
        34947,
        34978,
        35009,
        35039,
        35069,
        35099,
        35129,
        35159,
        35188,
        35219,
        35250,
        35281,
        35312,
        35343,
        35374,
        35404,
        35434,
        35464,
        35494,
        35524,
        35554,
        35585,
        35616,
        35647,
        35678,
        35709,
        35740,
        35770,
        35800,
        35830,
        35860,
        35890,
        35919,
        35950,
        35981,
        36012,
        36043,
        36074,
        36105,
        36135,
        36165,
        36195,
        36225,
        36255,
        36284,
        36315,
        36346,
        36377,
        36408,
        36439,
        36470,
        36500,
        36530,
        36560,
        36590,
        36620,
        36649,
        36680,
        36711,
        36742,
        36773,
        36804,
        36835,
        36865,
        36895,
        36925,
        36955,
        36985,
        37015,
        37046,
        37077,
        37108,
        37139,
        37170,
        37201,
        37231,
        37261,
        37291,
        37321,
        37351,
        37380,
        37411,
        37442,
        37473,
        37504,
        37535,
        37566,
        37596,
        37626,
        37656,
        37686,
        37716,
        37745,
        37776,
        37807,
        37838,
        37869,
        37900,
        37931,
        37961,
        37991,
        38021,
        38051,
        38081,
        38110,
        38141,
        38172,
        38203,
        38234,
        38265,
        38296,
        38326,
        38356,
        38386,
        38416,
        38446,
        38476,
        38507,
        38538,
        38569,
        38600,
        38631,
        38662,
        38692,
        38722,
        38752,
        38782,
        38812,
        38841,
        38872,
        38903,
        38934,
        38965,
        38996,
        39027,
        39057,
        39087,
        39117,
        39147,
        39177,
        39206,
        39237,
        39268,
        39299,
        39330,
        39361,
        39392,
        39422,
        39452,
        39482,
        39512,
        39542,
        39571,
        39602,
        39633,
        39664,
        39695,
        39726,
        39757,
        39787,
        39817,
        39847,
        39877,
        39907,
        39937,
        39968,
        39999,
        40030,
        40061,
        40092,
        40123,
        40153,
        40183,
        40213,
        40243,
        40273,
        40302,
        40333,
        40364,
        40395,
        40426,
        40457,
        40488,
        40518,
        40548,
        40578,
        40608,
        40638,
        40667,
        40698,
        40729,
        40760,
        40791,
        40822,
        40853,
        40883,
        40913,
        40943,
        40973,
        41003,
        41032,
        41063,
        41094,
        41125,
        41156,
        41187,
        41218,
        41248,
        41278,
        41308,
        41338,
        41368,
        41398,
        41429,
        41460,
        41491,
        41522,
        41553,
        41584,
        41614,
        41644,
        41674,
        41704,
        41734,
        41763,
        41794,
        41825,
        41856,
        41887,
        41918,
        41949,
        41979,
        42009,
        42039,
        42069,
        42099,
        42128,
        42159,
        42190,
        42221,
        42252,
        42283,
        42314,
        42344,
        42374,
        42404,
        42434,
        42464,
        42493,
        42524,
        42555,
        42586,
        42617,
        42648,
        42679,
        42709,
        42739,
        42769,
        42799,
        42829,
        42859,
        42890,
        42921,
        42952,
        42983,
        43014,
        43045,
        43075,
        43105,
        43135,
        43165,
        43195,
        43224,
        43255,
        43286,
        43317,
        43348,
        43379,
        43410,
        43440,
        43470,
        43500,
        43530,
        43560,
        43589,
        43620,
        43651,
        43682,
        43713,
        43744,
        43775,
        43805,
        43835,
        43865,
        43895,
        43925,
        43954,
        43985,
        44016,
        44047,
        44078,
        44109,
        44140,
        44170,
        44200,
        44230,
        44260,
        44290,
        44320,
        44351,
        44382,
        44413,
        44444,
        44475,
        44506,
        44536,
        44566,
        44596,
        44626,
        44656,
        44685,
        44716,
        44747,
        44778,
        44809,
        44840,
        44871,
        44901,
        44931,
        44961,
        44991,
        45021,
        45050,
        45081,
        45112,
        45143,
        45174,
        45205,
        45236,
        45266,
        45296,
        45326,
        45356,
        45386,
        45415,
        45446,
        45477,
        45508,
        45539,
        45570,
        45601,
        45631,
        45661,
        45691,
        45721,
        45751,
        45781,
        45812,
        45843,
        45874,
        45905,
        45936,
        45967,
        45997,
        46027,
        46057,
        46087,
        46117,
        46146,
        46177,
        46208,
        46239,
        46270,
        46301,
        46332,
        46362,
        46392,
        46422,
        46452,
        46482,
        46511,
        46542,
        46573,
        46604,
        46635,
        46666,
        46697,
        46727,
        46757,
        46787,
        46817,
        46847,
        46876,
        46907,
        46938,
        46969,
        47000,
        47031,
        47062,
        47092,
        47122,
        47152,
        47182,
        47212,
        47242,
        47273,
        47304,
        47335,
        47366,
        47397,
        47428,
        47458,
        47488,
        47518,
        47548,
        47578,
        47607,
        47638,
        47669,
        47700,
        47731,
        47762,
        47793,
        47823,
        47853,
        47883,
        47913,
        47943,
        47972,
        48003,
        48034,
        48065,
        48096,
        48127,
        48158,
        48188,
        48218,
        48248,
        48278,
        48308,
        48337,
        48368,
        48399,
        48430,
        48461,
        48492,
        48523,
        48553,
        48583,
        48613,
        48643,
        48673,
        48703,
        48734,
        48765,
        48796,
        48827,
        48858,
        48889,
        48919,
        48949,
        48979,
        49009,
        49039,
        49068,
        49099,
        49130,
        49161,
        49192,
        49223,
        49254,
        49284,
        49314,
        49344,
        49374,
        49404,
        49433,
        49464,
        49495,
        49526,
        49557,
        49588,
        49619,
        49649,
        49679,
        49709,
        49739,
        49769,
        49798,
        49829,
        49860,
        49891,
        49922,
        49953,
        49984,
        50014,
        50044,
        50074,
        50104,
        50134,
        50164,
        50195,
        50226,
        50257,
        50288,
        50319,
        50350,
        50380,
        50410,
        50440,
        50470,
        50500,
        50529,
        50560,
        50591,
        50622,
        50653,
        50684,
        50715,
        50745,
        50775,
        50805,
        50835,
        50865,
        50894,
        50925,
        50956,
        50987,
        51018,
        51049,
        51080,
        51110,
        51140,
        51170,
        51200,
        51230,
        51259,
        51290,
        51321,
        51352,
        51383,
        51414,
        51445,
        51475,
        51505,
        51535,
        51565,
        51595,
        51625,
        51656,
        51687,
        51718,
        51749,
        51780,
        51811,
        51841,
        51871,
        51901,
        51931,
        51961,
        51990,
        52021,
        52052,
        52083,
        52114,
        52145,
        52176,
        52206,
        52236,
        52266,
        52296,
        52326,
        52355,
        52386,
        52417,
        52448,
        52479,
        52510,
        52541,
        52571,
        52601,
        52631,
        52661,
        52691,
        52720,
        52751,
        52782,
        52813,
        52844,
        52875,
        52906,
        52936,
        52966,
        52996,
        53026,
        53056,
        53086,
        53117,
        53148,
        53179,
        53210,
        53241,
        53272,
        53302,
        53332,
        53362,
        53392,
        53422,
        53451,
        53482,
        53513,
        53544,
        53575,
        53606,
        53637,
        53667,
        53697,
        53727,
        53757,
        53787,
        53816,
        53847,
        53878,
        53909,
        53940,
        53971,
        54002,
        54032,
        54062,
        54092,
        54122,
        54152,
        54181,
        54212,
        54243,
        54274,
        54305,
        54336,
        54367,
        54397,
        54427,
        54457,
        54487,
        54517,
        54547,
        54578,
        54609,
        54640,
        54671,
        54702,
        54733,
        54763,
        54793,
        54823,
        54853,
        54883,
        54912,
        54943,
        54974,
        55005,
        55036,
        55067,
        55098,
        55128,
        55158,
        55188,
        55218,
        55248,
        55277,
        55308,
        55339,
        55370,
        55401,
        55432,
        55463,
        55493,
        55523,
        55553,
        55583,
        55613,
        55642,
        55673,
        55704,
        55735,
        55766,
        55797,
        55828,
        55858,
        55888,
        55918,
        55948,
        55978,
        56008,
        56039,
        56070,
        56101,
        56132,
        56163,
        56194,
        56224,
        56254,
        56284,
        56314,
        56344,
        56373,
        56404,
        56435,
        56466,
        56497,
        56528,
        56559,
        56589,
        56619,
        56649,
        56679,
        56709,
        56738,
        56769,
        56800,
        56831,
        56862,
        56893,
        56924,
        56954,
        56984,
        57014,
        57044,
        57074,
        57103,
        57134,
        57165,
        57196,
        57227,
        57258,
        57289,
        57319,
        57349,
        57379,
        57409,
        57439,
        57469,
        57500,
        57531,
        57562,
        57593,
        57624,
        57655,
        57685,
        57715,
        57745,
        57775,
        57805,
        57834,
        57865,
        57896,
        57927,
        57958,
        57989,
        58020,
        58050,
        58080,
        58110,
        58140,
        58170,
        58199,
        58230,
        58261,
        58292,
        58323,
        58354,
        58385,
        58415,
        58445,
        58475,
        58505,
        58535,
        58564,
        58595,
        58626,
        58657,
        58688,
        58719,
        58750,
        58780,
        58810,
        58840,
        58870,
        58900,
        58930,
        58961,
        58992,
        59023,
        59054,
        59085,
        59116,
        59146,
        59176,
        59206,
        59236,
        59266,
        59295,
        59326,
        59357,
        59388,
        59419,
        59450,
        59481,
        59511,
        59541,
        59571,
        59601,
        59631,
        59660,
        59691,
        59722,
        59753,
        59784,
        59815,
        59846,
        59876,
        59906,
        59936,
        59966,
        59996,
        60025,
        60056,
        60087,
        60118,
        60149,
        60180,
        60211,
        60241,
        60271,
        60301,
        60331,
        60361,
        60391,
        60422,
        60453,
        60484,
        60515,
        60546,
        60577,
        60607,
        60637,
        60667,
        60697,
        60727,
        60756,
        60787,
        60818,
        60849,
        60880,
        60911,
        60942,
        60972,
        61002,
        61032,
        61062,
        61092,
        61121,
        61152,
        61183,
        61214,
        61245,
        61276,
        61307,
        61337,
        61367,
        61397,
        61427,
        61457,
        61486,
        61517,
        61548,
        61579,
        61610,
        61641,
        61672,
        61702,
        61732,
        61762,
        61792,
        61822,
        61852,
        61883,
        61914,
        61945,
        61976,
        62007,
        62038,
        62068,
        62098,
        62128,
        62158,
        62188,
        62217,
        62248,
        62279,
        62310,
        62341,
        62372,
        62403,
        62433,
        62463,
        62493,
        62523,
        62553,
        62582,
        62613,
        62644,
        62675,
        62706,
        62737,
        62768,
        62798,
        62828,
        62858,
        62888,
        62918,
        62947,
        62978,
        63009,
        63040,
        63071,
        63102,
        63133,
        63163,
        63193,
        63223,
        63253,
        63283,
        63313,
        63344,
        63375,
        63406,
        63437,
        63468,
        63499,
        63529,
        63559,
        63589,
        63619,
        63649,
        63678,
        63709,
        63740,
        63771,
        63802,
        63833,
        63864,
        63894,
        63924,
        63954,
        63984,
        64014,
        64043,
        64074,
        64105,
        64136,
        64167,
        64198,
        64229,
        64259,
        64289,
        64319,
        64349,
        64379,
        64408,
        64439,
        64470,
        64501,
        64532,
        64563,
        64594,
        64624,
        64654,
        64684,
        64714,
        64744,
        64774,
        64805,
        64836,
        64867,
        64898,
        64929,
        64960,
        64990,
        65020,
        65050,
        65080,
        65110,
        65139,
        65170,
        65201,
        65232,
        65263,
        65294,
        65325,
        65355,
        65385,
        65415,
        65445,
        65475,
        65504,
        65535,
        65566,
        65597,
        65628,
        65659,
        65690,
        65720,
        65750,
        65780,
        65810,
        65840,
        65869,
        65900,
        65931,
        65962,
        65993,
        66024,
        66055,
        66085,
        66115,
        66145,
        66175,
        66205,
        66235,
        66266,
        66297,
        66328,
        66359,
        66390,
        66421,
        66451,
        66481,
        66511,
        66541,
        66571,
        66600,
        66631,
        66662,
        66693,
        66724,
        66755,
        66786,
        66816,
        66846,
        66876,
        66906,
        66936,
        66965,
        66996,
        67027,
        67058,
        67089,
        67120,
        67151,
        67181,
        67211,
        67241,
        67271,
        67301,
        67330,
        67361,
        67392,
        67423,
        67454,
        67485,
        67516,
        67546,
        67576,
        67606,
        67636,
        67666,
        67696,
        67727,
        67758,
        67789,
        67820,
        67851,
        67882,
        67912,
        67942,
        67972,
        68002,
        68032,
        68061,
        68092,
        68123,
        68154,
        68185,
        68216,
        68247,
        68277,
        68307,
        68337,
        68367,
        68397,
        68426,
        68457,
        68488,
        68519,
        68550,
        68581,
        68612,
        68642,
        68672,
        68702,
        68732,
        68762,
        68791,
        68822,
        68853,
        68884,
        68915,
        68946,
        68977,
        69007,
        69037,
        69067,
        69097,
        69127,
        69157,
        69188,
        69219,
        69250,
        69281,
        69312,
        69343,
        69373,
        69403,
        69433,
        69463,
        69493,
        69522,
        69553,
        69584,
        69615,
        69646,
        69677,
        69708,
        69738,
        69768,
        69798,
        69828,
        69858,
        69887,
        69918,
        69949,
        69980,
        70011,
        70042,
        70073,
        70103,
        70133,
        70163,
        70193,
        70223,
        70252,
        70283,
        70314,
        70345,
        70376,
        70407,
        70438,
        70468,
        70498,
        70528,
        70558,
        70588,
        70618,
        70649,
        70680,
        70711,
        70742,
        70773,
        70804,
        70834,
        70864,
        70894,
        70924,
        70954,
        70983,
        71014,
        71045,
        71076,
        71107,
        71138,
        71169,
        71199,
        71229,
        71259,
        71289,
        71319,
        71348,
        71379,
        71410,
        71441,
        71472,
        71503,
        71534,
        71564,
        71594,
        71624,
        71654,
        71684,
        71713,
        71744,
        71775,
        71806,
        71837,
        71868,
        71899,
        71929,
        71959,
        71989,
        72019,
        72049,
        72079,
        72110,
        72141,
        72172,
        72203,
        72234,
        72265,
        72295,
        72325,
        72355,
        72385,
        72415,
        72444,
        72475,
        72506,
        72537,
        72568,
        72599,
        72630,
        72660,
        72690,
        72720,
        72750,
        72780,
        72809,
        72840,
        72871,
        72902,
        72933,
        72964,
        72995,
        73025,
        73055,
        73085,
        73115,
        73145,
        73174,
        73205,
        73236,
        73267,
        73298,
        73329,
        73360,
        73390,
        73420,
        73450,
        73480,
        73510,
        73540,
        73571,
        73602,
        73633,
        73664,
        73695,
        73726,
        73756,
        73786,
        73816,
        73846,
        73876,
        73905,
        73936,
        73967,
        73998,
        74029,
        74060,
        74091,
        74121,
        74151,
        74181,
        74211,
        74241,
        74270,
        74301,
        74332,
        74363,
        74394,
        74425,
        74456,
        74486,
        74516,
        74546,
        74576,
        74606,
        74635,
        74666,
        74697,
        74728,
        74759,
        74790,
        74821,
        74851,
        74881,
        74911,
        74941,
        74971,
        75001,
        75032,
        75063,
        75094,
        75125,
        75156,
        75187,
        75217,
        75247,
        75277,
        75307,
        75337,
        75366,
        75397,
        75428,
        75459,
        75490,
        75521,
        75552,
        75582,
        75612,
        75642,
        75672,
        75702,
        75731,
        75762,
        75793,
        75824,
        75855,
        75886,
        75917,
        75947,
        75977,
        76007,
        76037,
        76067,
        76096,
        76127,
        76158,
        76189,
        76220,
        76251,
        76282,
        76312,
        76342,
        76372,
        76402,
        76432,
        76462,
        76493,
        76524,
        76555,
        76586,
        76617,
        76648,
        76678,
        76708,
        76738,
        76768,
        76798,
        76827,
        76858,
        76889,
        76920,
        76951,
        76982,
        77013,
        77043,
        77073,
        77103,
        77133,
        77163,
        77192,
        77223,
        77254,
        77285,
        77316,
        77347,
        77378,
        77408,
        77438,
        77468,
        77498,
        77528,
        77557,
        77588,
        77619,
        77650,
        77681,
        77712,
        77743,
        77773,
        77803,
        77833,
        77863,
        77893,
        77923,
        77954,
        77985,
        78016,
        78047,
        78078,
        78109,
        78139,
        78169,
        78199,
        78229,
        78259,
        78288,
        78319,
        78350,
        78381,
        78412,
        78443,
        78474,
        78504,
        78534,
        78564,
        78594,
        78624,
        78653,
        78684,
        78715,
        78746,
        78777,
        78808,
        78839,
        78869,
        78899,
        78929,
        78959,
        78989,
        79018,
        79049,
        79080,
        79111,
        79142,
        79173,
        79204,
        79234,
        79264,
        79294,
        79324,
        79354,
        79384,
        79415,
        79446,
        79477,
        79508,
        79539,
        79570,
        79600,
        79630,
        79660,
        79690,
        79720,
        79749,
        79780,
        79811,
        79842,
        79873,
        79904,
        79935,
        79965,
        79995,
    )
